@@ -934,18 +934,6 @@ def get_args_parser(
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
             add_help=False
         )
-        parser.add_argument(
-            '-v', '--verbose',
-            help    = 'Increase logging verbosity.',
-            dest    = 'verbosity',
-            action  = "count"
-        )
-        parser.add_argument(
-            '-q', '--quiet',
-            help    = 'Decrease logging verbosity.',
-            dest    = '__quiet',
-            action  = "count"
-        )
         parser.add_argument(
             '-h', '--help',
             help    = 'Display this help information.',
