@@ -11,6 +11,7 @@ versions of these utilities. """
 import os
 import tempfile
 import errno
+import hashlib
 from typing import Any, Union, Callable, List
 from ptutils.encoding import encode_json, decode_json, encode_yaml, decode_yaml, require_yaml
 from ptutils.undefined import UNDEFINED, Undefined, is_undefined
@@ -21,7 +22,7 @@ from ptutils.undefined import UNDEFINED, Undefined, is_undefined
 try:
     import tarfile
     HAVE_TAR = True
-except ImportError:
+except ImportError:  # pragma: no cover
     HAVE_TAR = False
 
 # -----------------------------------------------------------------------------------------------------------------------
@@ -100,7 +101,8 @@ def get_hash_tmp_dir(relpath: str) -> str:
     str
         A temporary directory name as a string.
     """
-    return os.path.join( tempfile.gettempdir(), hash(relpath) )
+    h = hashlib.md5(relpath.encode('utf-8')).hexdigest()
+    return os.path.join( tempfile.gettempdir(), h )
 
 
 # ------------------------------------------------------------------------------------------------------------------------
@@ -259,7 +261,7 @@ def require_tar() -> None:
     Exception
         When `import tarfile` raises `ImportError`
     """
-    if not HAVE_TAR:
+    if not HAVE_TAR:  # pragma: no cover
         raise Exception("Tarfile support is not available on this platform.")
 
 
@@ -285,17 +287,56 @@ def extract_archive(archive: str, folder: str) -> None:
         As per `tarfile.open` or `tarfile.TarFile.extractall`
     """
     filetype = get_filetype(archive)
-    if filetype == 'archive-zip':
-        raise NotImplementedError('No support for .zip archives')
-    elif filetype in ['archive-tar', 'archive-gzip', 'archive-bzip2']:
+    if filetype in ['archive-tar', 'archive-gzip', 'archive-bzip2']:
         require_tar()
-        tar = tarfile.open(archive)
+        modes = {
+            'archive-tar':   "r",
+            'archive-gzip':  "r:gz",
+            'archive-bzip2': "r:bz2"
+        }
+        tar = tarfile.open(archive, mode=modes[filetype])
         tar.extractall(folder)
         tar.close()
     else:
         raise NotImplementedError(f"No extraction support for files of type '{filetype}'.")
 
 
+# ------------------------------------------------------------------------------------------------------------------------
+def compress_archive(archive: str, folder: str):
+    """
+    Compress the specified folder into an archive file.
+
+    Parameters
+    ----------
+    archive : str
+        Path to the archive file to create.
+    folder : str
+        Path to the folder from which to populate the archive's contents.
+
+    Raises
+    ------
+    NotImplementedError
+        When the archive pointed to by `archive` is of an unsupported filetype.
+    Exception
+        when tarfile support is unavailable on this platform.
+    Exception
+        As per `tarfile.open` or `tarfile.TarFile.extractall`
+    """
+    filetype = get_filetype(archive)
+    if filetype in ['archive-tar', 'archive-gzip', 'archive-bzip2']:
+        modes = {
+            'archive-tar':   "w",
+            'archive-gzip':  "w:gz",
+            'archive-bzip2': "w:bz2"
+        }
+        require_tar()
+        with tarfile.open(archive, mode = modes[filetype]) as tar:
+            tar.add(folder, arcname = os.path.sep)
+            tar.close()
+    else:
+        raise NotImplementedError(f"No compression support for files of type '{filetype}'.")
+
+
 # ------------------------------------------------------------------------------------------------------------------------
 def load_txt(filename: str) -> str:
     """
